/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * A Data Lake Analytics account object, containing all information associated
 * with the named Data Lake Analytics account.
 *
 * @extends models['Resource']
 */
class DataLakeAnalyticsAccountBasic extends models['Resource'] {
  /**
   * Create a DataLakeAnalyticsAccountBasic.
   * @member {string} [provisioningState] the provisioning status of the Data
   * Lake Analytics account. Possible values include: 'Failed', 'Creating',
   * 'Running', 'Succeeded', 'Patching', 'Suspending', 'Resuming', 'Deleting',
   * 'Deleted', 'Undeleting', 'Canceled'
   * @member {string} [state] the state of the Data Lake Analytics account.
   * Possible values include: 'Active', 'Suspended'
   * @member {date} [creationTime] the account creation time.
   * @member {date} [lastModifiedTime] the account last modified time.
   * @member {string} [endpoint] the full CName endpoint for this account.
   * @member {uuid} [accountId] The unique identifier associated with this Data
   * Lake Analytics account.
   */
  constructor() {
    super();
  }

  /**
   * Defines the metadata of DataLakeAnalyticsAccountBasic
   *
   * @returns {object} metadata of DataLakeAnalyticsAccountBasic
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'DataLakeAnalyticsAccountBasic',
      type: {
        name: 'Composite',
        className: 'DataLakeAnalyticsAccountBasic',
        modelProperties: {
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          name: {
            required: false,
            readOnly: true,
            serializedName: 'name',
            type: {
              name: 'String'
            }
          },
          type: {
            required: false,
            readOnly: true,
            serializedName: 'type',
            type: {
              name: 'String'
            }
          },
          location: {
            required: true,
            serializedName: 'location',
            type: {
              name: 'String'
            }
          },
          tags: {
            required: false,
            serializedName: 'tags',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          },
          provisioningState: {
            required: false,
            readOnly: true,
            serializedName: 'properties.provisioningState',
            type: {
              name: 'Enum',
              allowedValues: [ 'Failed', 'Creating', 'Running', 'Succeeded', 'Patching', 'Suspending', 'Resuming', 'Deleting', 'Deleted', 'Undeleting', 'Canceled' ]
            }
          },
          state: {
            required: false,
            readOnly: true,
            serializedName: 'properties.state',
            type: {
              name: 'Enum',
              allowedValues: [ 'Active', 'Suspended' ]
            }
          },
          creationTime: {
            required: false,
            readOnly: true,
            serializedName: 'properties.creationTime',
            type: {
              name: 'DateTime'
            }
          },
          lastModifiedTime: {
            required: false,
            readOnly: true,
            serializedName: 'properties.lastModifiedTime',
            type: {
              name: 'DateTime'
            }
          },
          endpoint: {
            required: false,
            readOnly: true,
            serializedName: 'properties.endpoint',
            type: {
              name: 'String'
            }
          },
          accountId: {
            required: false,
            readOnly: true,
            serializedName: 'properties.accountId',
            type: {
              name: 'String'
            }
          }
        }
      }
    };
  }
}

module.exports = DataLakeAnalyticsAccountBasic;
